@@ -1,5 +1,5 @@
 #
-# $Id: Json.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
+# $Id: Json.pm,v 6bd6acfc81d5 2019/03/13 09:56:26 gomor $
 #
 # file::json Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Text);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6fa51436f298 $',
+      revision => '$Revision: 6bd6acfc81d5 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -20,12 +20,14 @@ sub brik_properties {
          output => [ qw(file) ],
          encoding => [ qw(utf8|ascii) ],
          overwrite => [ qw(0|1) ],
+        _sj => [ qw(INTERNAL) ],
       },
       attributes_default => {
          overwrite => 1,
       },
       commands => {
          read => [ qw(input_file|OPTIONAL) ],
+         read_next => [ qw(input_file|OPTIONAL) ],
          write => [ qw($json_hash output_file|OPTIONAL) ],
          is_valid => [ qw(input_file|OPTIONAL) ],
       },
@@ -46,6 +48,15 @@ sub brik_use_properties {
    };
 }
 
+sub brik_init {
+   my $self = shift;
+
+   my $sj = Metabrik::String::Json->new_from_brik_init($self) or return;
+   $self->_sj($sj);
+
+   return $self->SUPER::brik_init;
+}
+
 sub read {
    my $self = shift;
    my ($input) = @_;
@@ -53,12 +64,25 @@ sub read {
    $input ||= $self->input;
    $self->brik_help_run_undef_arg('read', $input) or return;
 
+   my $sj = $self->_sj;
+
    my $data = $self->SUPER::read($input) or return;
 
-   my $sj = Metabrik::String::Json->new_from_brik_init($self) or return;
-   my $json = $sj->decode($data) or return;
+   return $sj->decode($data);
+}
 
-   return $json;
+sub read_next {
+   my $self = shift;
+   my ($input) = @_;
+
+   $input ||= $self->input;
+   $self->brik_help_run_undef_arg('read_next', $input) or return;
+
+   my $sj = $self->_sj;
+
+   my $data = $self->SUPER::read_line($input) or return;
+
+   return $sj->decode($data);
 }
 
 sub write {
@@ -67,12 +91,22 @@ sub write {
 
    $output ||= $self->output;
    $self->brik_help_run_undef_arg('write', $json_hash) or return;
+   $self->brik_help_run_invalid_arg('write', $json_hash, 'ARRAY', 'HASH')
+      or return;
    $self->brik_help_run_undef_arg('write', $output) or return;
 
-   my $sj = Metabrik::String::Json->new_from_brik_init($self) or return;
-   my $data = $sj->encode($json_hash) or return;
+   my $sj = $self->_sj;
 
-   $self->SUPER::write($data, $output) or return;
+   # Always make it an ARRAY
+   $json_hash = ref($json_hash) eq 'ARRAY' ? $json_hash : [ $json_hash ];
+
+   my @data = ();
+   for my $this (@$json_hash) {
+      my $data = $sj->encode($this) or next;
+      push @data, $data;
+   }
+
+   $self->SUPER::write(\@data, $output) or return;
 
    return $output;
 }
@@ -86,7 +120,8 @@ sub is_valid {
 
    my $data = $self->SUPER::read($input) or return;
 
-   my $sj = Metabrik::String::Json->new_from_brik_init($self) or return;
+   my $sj = $self->_sj;
+
    return $sj->is_valid($data);
 }
 
@@ -100,7 +135,7 @@ Metabrik::File::Json - file::json Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2019, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
