@@ -1,5 +1,5 @@
 #
-# $Id: Process.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
+# $Id: Process.pm,v 6bd6acfc81d5 2019/03/13 09:56:26 gomor $
 #
 # system::process Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6fa51436f298 $',
+      revision => '$Revision: 6bd6acfc81d5 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -33,6 +33,7 @@ sub brik_properties {
          is_running => [ qw(process) ],
          is_running_from_string => [ qw(string) ],
          get_pid_from_string => [ qw(string) ],
+         get_pid_list_from_string => [ qw(string) ],
          get_process_info => [ qw(process) ],
          kill => [ qw(process|pid) ],
          start => [ qw($sub) ],
@@ -66,6 +67,7 @@ sub brik_properties {
       need_packages => {
          ubuntu => [ qw(procps) ],
          debian => [ qw(procps) ],
+         kali => [ qw(procps) ],
       },
    };
 }
@@ -168,6 +170,26 @@ sub get_pid_from_string {
    return 0;
 }
 
+sub get_pid_list_from_string {
+   my $self = shift;
+   my ($string) = @_;
+
+   $self->brik_help_run_undef_arg('get_pid_list_from_string', $string)
+      or return;
+
+   my @pids = ();
+
+   my $list = $self->list or return;
+   for my $this (@$list) {
+      my $command = $this->{COMMAND};
+      if ($command =~ m{$string}i) {
+         push @pids, $this->{PID};
+      }
+   }
+
+   return \@pids;
+}
+
 sub get_process_info {
    my $self = shift;
    my ($process) = @_;
@@ -527,7 +549,7 @@ Metabrik::System::Process - system::process Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2019, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
