@@ -1,5 +1,5 @@
 #
-# $Id: Universal.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
+# $Id: Universal.pm,v 6bd6acfc81d5 2019/03/13 09:56:26 gomor $
 #
 # time::universal Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6fa51436f298 $',
+      revision => '$Revision: 6bd6acfc81d5 $',
       tags => [ qw(unstable timezone) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -292,6 +292,14 @@ sub to_timestamp {
          $timestamp .= sprintf(".%03d", $msec);
       }
    }
+   # 20190115
+   elsif ($string =~ m{^(\d{4})(\d{2})(\d{2})$}) {
+      $timestamp = Time::Local::timelocal(0, 0, 12, $3, $2-1, $1);
+      if ($self->use_hires) {
+         my $msec = 0;
+         $timestamp .= sprintf(".%03d", $msec);
+      }
+   }
    # Wed Nov  9 07:01:18 2016
    elsif ($string =~ m{^\S+\s+(\S+)\s+(\d+)\s+(\d+):(\d+):(\d+)\s+(\d+)$}) {
       my $mon = $1;
@@ -349,6 +357,25 @@ sub to_timestamp {
          $timestamp .= sprintf(".%03d", $msec);
       }
    }
+   # 2019-01-07 17:02
+   elsif ($string =~ m{^(\d{4})\-(\d{2})\-(\d{2}) (\d{2}):(\d{2})$}) {
+      my $mon = $2 - 1;
+      my $mday = $3;
+      my $hour = $4;
+      my $min = $5;
+      my $year = $1;
+      $timestamp = Time::Local::timelocal(0, $min, $hour, $mday, $mon, $year);
+   }
+   # 2019-01-07 11:40:24
+   elsif ($string =~ m{^(\d{4})\-(\d{2})\-(\d{2}) (\d{2}):(\d{2}):(\d{2})$}) {
+      my $mon = $2 - 1;
+      my $mday = $3;
+      my $hour = $4;
+      my $min = $5;
+      my $sec = $6;
+      my $year = $1;
+      $timestamp = Time::Local::timelocal($sec, $min, $hour, $mday, $mon, $year);
+   }
    # 2000-10-20T00:00:00.000-04:00
    elsif ($string =~ m{^(\d{4})\-(\d{2})\-(\d{2})T(\d{2}):(\d{2}):(\d{2})\.(\d{3})}) {
       my $mon = $2 - 1;
@@ -380,7 +407,7 @@ Metabrik::Time::Universal - time::universal Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2019, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
